==> tiki-9.7.tar.bz2: tiki-9.7/lang/ca/language.js <==
/* 
 * Javascript translation definition
 * Example in Catalan
 * 
 * $Id: language.js 41889 2012-06-10 16:47:38Z xavidp $
 */

lang = {
	"Very Secure" : "Molt segura",
	"Secure" : "Segura",
	"Very Strong" : "Molt forta",
	"Strong" : "Forta",
	"Average" : "Intermitja",
	"Weak" : "Fluixa",
	"Very Weak" : "Molt fluixa",
	"Strength" : "Força",
	"Valid User Name" : "Nom d'usuari vàlid",
	"Passwords match" : "Les contrasenyes coincideixen",
	"Passwords don't match" : "Les contrasenyes NO coincideixen",
	"Valid Email" : "Correu-e vàlid",
	"Close" : "Tancar",
	"Submit" : "Enviar",
	"Insert" : "Inserir",
	"Replace" : "Substituir",
	"Match" : "Igual",
	"Do not match" : "Diferent",
	"Advanced options" : "Opcions avançades",
	"URL to open this file with WebDAV" : "URL per a obrir aquest arxiu a través de WebDAV",
	"To My Location" : "A La Meva Localització",
	"What address are you looking for?" : "Quina adreça estàs cercant?",
	"Search Location" : "Cerca una Localització",
	"Pick a file." : "Escull un arxiu",
	"Add Field" : "Afegeix un camp",
	"Edit Field" : "Modifica un camp",
	"Removing the field will result in data loss. Are you sure?" : "La supressió del camp comportarà supressió de dades. N'estàs segur/a?",
	"Save" : "Desa-ho",
	"Cancel" : "Cancel·la-ho",
	"Delete" : "Suprimeix-ho",	
	"Unassign module" : "Deassigna el mòdul",
	"Edit module" : "Modifica el mòdul",
	"Edit module:" : "Modifica el mòdul:",
	"Favorite" : "Favorit",
	"What address are you looking for?" : "Quina adreça estàs cercant?",
	"Filter:" : "Filtre:",
	"Please enter a page name" : "Si us plau, introdueix un nom de pàgina",
	"Change Highlighter" : "Canvia el Ressaltador",
	"Toggle Highlighter" : "Commuta el Ressaltador",
	"Are you sure you want to unassign this module?" : "N'estàs segur que vols desassignar aquest mòdul?"
	// remember the IE does not support ending comma on last item
};

==> tiki-19.1.tar.bz2: tiki-19.1/lang/ca/language.js <==
/*
 * Javascript translation definition
 * Example in Catalan
 *
 * $Id: language.js 64615 2017-11-17 23:53:38Z rjsmelo $
 */

lang = {
	"Default" : "Per omissió",
	"Very Secure" : "Molt Segura",
	"Secure" : "Segura",
	"Very Strong" : "Molt forta",
	"Strong" : "Forta",
	"Average" : "Intermitja",
	"Weak" : "Fluixa",
	"Very Weak" : "Molt fluixa",
	"Strength" : "Força",
	"Valid User Name" : "Nom d'usuari vàlid",
	"Passwords match" : "Les contrasenyes coincideixen",
	"Valid Email" : "Correu-e vàlid",
	"Close" : "Tancar",
	"Submit" : "Enviar",
	"Insert" : "Inserir",
	"Replace" : "Substituir",
	"Match" : "Igual",
	"Do not match" : "Diferent",
	"Advanced options" : "Opcions avançades",
	"Pick a file." : "Escull un arxiu",
	"Add Field" : "Afegeix un camp",
	"Edit Field" : "Modifica un camp",
	"Removing the field will result in data loss. Are you sure?" : "La supressió del camp comportarà supressió de dades. N'estàs segur/a?",
	"Save" : "Desa-ho",
	"Cancel" : "Cancel·la-ho",
	"Delete" : "Suprimeix-ho",
	"Unassign module" : "Deassigna el mòdul",
	"Edit module" : "Modifica el mòdul",
	"Edit module:" : "Modifica el mòdul:",
	"Favorite" : "Favorit",
	"What address are you looking for?" : "Quina adreça estàs cercant?",
	"Filter:" : "Filtre:",
	"Please enter a page name" : "Si us plau, introdueix un nom de pàgina",
	"Change Highlighter" : "Canvia el Ressaltador",
	"Toggle Highlighter" : "Commuta el Ressaltador",
	"Are you sure you want to unassign this module?" : "N'estàs segur que vols desassignar aquest mòdul?",
	"Search Location" : "Cerca una adreça",
	"To My Location" : "Localitza la meva posició",
	"StreetView is not available at this specific point on the map. Zoom in as needed and make sure to click on a blue line." : "La funció StreetView hi és disponible en aquest punt específic sobre el mapa. Aproxima't amb el zoom el que et calgui i assegura't de fer clic sobre una línia blava.",
	"Browse Files" : "Obre la llista d'arxius",
	// remember the IE does not support ending comma on last item
	"Bogus entry" : "bogus entry"
};
